//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// KBIcon class - abstract common superclass of Keyboard GUI icons
//
import java.awt.Color;
import java.awt.Canvas;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Frame;
import java.awt.BorderLayout;

/**
 * Abstract common superclass of Keyboard GUI icons
 */
public abstract class KBIcon extends Canvas {

	/**
	 * Default unit size of an icon.
	 */
	public static final int	DEFAULT_SIZE		= 24;

	// the legend printed on the icon, and the icon dimensions
	protected String	legend;//		= null;
	protected boolean	show_legend		= true;
	protected Dimension	pref_size;//		= null;

	// highlighting colour, or null if none set
	protected Color		highlight_colour;//	= null;


	/**
	 * Create an icon with the specified legend, unit size,
	 * width, and height factor (in %).  A null legend
	 * creates a 'blank'.
	 */
	public KBIcon( String legend, int unit_size, int width_factor,
			int height_factor ) {
		this.pref_size	= new Dimension(
					unit_size * width_factor  / 100,
					unit_size * height_factor / 100 );
		set_legend( legend );
	}

	/**
	 * Create an icon with the specified legend, and width factor,
	 * and default unit size.
	 */
	public KBIcon( String legend, int width_factor ) {
		this( legend, DEFAULT_SIZE, width_factor, 100 );
	}

	/*
	 * Return dimensions.
	 */
	public synchronized Dimension getPreferredSize() {
		return ( pref_size ); }
	public synchronized Dimension getMinimumSize() {
		return ( pref_size ); }

	/**
	 * Re-render the complete graphic if anything about this icon
	 * has changed, by simply calling paint().
	 */
	public synchronized void update( Graphics g ) { paint( g ); }

	/*
	 * Standard get/set methods.
	 */
	public synchronized String get_legend()	{ return ( legend ); }
	public synchronized void set_legend( String legend ) {
		if ( ! legend.equals( this.legend ) ) {
			this.legend = legend; repaint();
		}
	}
	public synchronized void show_legend( boolean show_legend ) {
		if ( show_legend != this.show_legend ) {
			this.show_legend = show_legend; repaint();
		}
	}
	public synchronized Color get_colour()	{ return ( getForeground() ); }
	public synchronized void set_colour( Color colour ) {
		if ( colour != getForeground() ) {
			setForeground( colour ); repaint();
		}
	}
	public synchronized Color get_bgcolour() { return ( getBackground() ); }
	public synchronized void set_bgcolour( Color colour ) {
		if ( colour != getBackground() ) {
			setBackground( colour ); repaint();
		}
	}
	public synchronized void set_highlight( Color colour ) {
		if ( colour != highlight_colour ) {
			highlight_colour = colour; repaint();
		}
	}
	public synchronized void clear_highlight() {
		set_highlight( null );
	}
}
